@@ -10,7 +10,8 @@
 
 // createBegin: here we set up the default observation parameters.
 
-+createBegin: (id) aZone {
++ createBegin:  aZone 
+{
   HeatbugBatchSwarm * obj;
 
   // Superclass createBegin to allocate ourselves.
@@ -23,15 +24,16 @@
   return obj;
 }
 
--buildObjects {
-  id modelZone;					       // zone for model.
-
+- buildObjects
+{
   [super buildObjects];
 
-  // create a zone for the model, create the model there.
+  // IMPORTANT!!
+  // Create the model inside us - no longer create `Zone's explicitly.
+  // The Zone is now created implicitly through the call to create the
+  // `Swarm' inside `self'.
 
-  modelZone = [Zone create: [self getZone]];
-  heatbugModelSwarm = [HeatbugModelSwarm create: modelZone];
+  heatbugModelSwarm = [HeatbugModelSwarm create: self];
 
   // In HeatbugObserverSwarm, we'd build some probes and wait for a
   // user control event (this allows the user to fiddle with the 
@@ -41,8 +43,10 @@
   // the model.setup parameter file (which contains values for the model
   // specific variables such as numBugs etc.).
   
-  [ObjectLoader load: self fromFileNamed: "batch.setup"] ;
-  [ObjectLoader load: heatbugModelSwarm fromFileNamed: "experiment.setup"] ;
+  [ObjectLoader load: self 
+                fromAppDataFileNamed: "batch.setup"];
+  [ObjectLoader load: heatbugModelSwarm
+                fromAppDataFileNamed: "experiment.setup"];
 
   // Now, let the model swarm build its objects.
   [heatbugModelSwarm buildObjects];
@@ -59,7 +63,7 @@
   // aspects of the model...
 
   if(loggingFrequency){
-    unhappyGraph = [EZGraph createBegin: [self getZone]];
+    unhappyGraph = [EZGraph createBegin: self];
     [unhappyGraph setGraphics: 0] ;
     [unhappyGraph setFileOutput: 1] ;
     unhappyGraph = [unhappyGraph createEnd] ;
@@ -75,7 +79,8 @@
 // Create the actions necessary for the simulation. This is where
 // the schedule is built (but not run!)
 
--buildActions {
+- buildActions 
+{
   [super buildActions];
   
   // First, let our model swarm build its own schedule.
@@ -87,7 +92,7 @@
     // Create an ActionGroup for display. This is pretty minimal in this
     // case. Note, there's no doTkEvents message - no control panel!
 
-    displayActions = [ActionGroup create: [self getZone]];
+    displayActions = [ActionGroup create: self];
 
     // Now schedule the update of the unhappyGraph, which will in turn 
     // cause the fileI/O to occur...
@@ -95,7 +100,7 @@
     [displayActions createActionTo: unhappyGraph message: M(step)];
 
     // the displaySchedule controls how often we write data out.
-    displaySchedule = [Schedule createBegin: [self getZone]];
+    displaySchedule = [Schedule createBegin: self];
     [displaySchedule setRepeatInterval: loggingFrequency];
     displaySchedule = [displaySchedule createEnd];
 
@@ -105,7 +110,7 @@
   // We also add in a "stopSchedule", another schedule with an absolute
   // time event - stop the system at time . 
 
-  stopSchedule = [Schedule create: [self getZone]];
+  stopSchedule = [Schedule create: self];
   [stopSchedule at: experimentDuration 
     createActionTo: self 
          message: M(stopRunning)];
@@ -114,7 +119,8 @@
 }  
 
 // activateIn: - get the Swarm ready to run.
--activateIn: (id) swarmContext {
+- activateIn:  swarmContext 
+{
   // First, activate ourselves (just pass along the context).
   [super activateIn: swarmContext];
 
@@ -136,9 +142,10 @@
 // a friendly message printed out here just in case someone is confused
 // when they run heatbugs and see no graphics.
 
--go {
+- go 
+{
   printf(
-    "You typed 'heatbugs -batchmode', so we're running without graphics.\n");
+    "You typed `heatbugs -b' or `heatbugs --batch', so we're running without graphics.\n");
 
   printf("Heatbugs is running for %d timesteps.\n",experimentDuration) ;
  
@@ -154,7 +161,8 @@
 // that's running and close our output file(s) by dropping the EZGraph which
 // "owns" the sequence(s) we are logging.
 
--stopRunning {
+- stopRunning 
+{
   [getTopLevelActivity() terminate]; // Terminate the simulation.
 
   if(loggingFrequency)
