@@ -8,11 +8,8 @@
 
 #import "Heatbug.h"
 #import "HeatSpace.h"
-#import <space.h>
-#import <activity.h>
-#import <collections.h>
+#import <space.h> // Grid2d
 #import <objectbase/Swarm.h>
-#import <objectbase.h>
 
 @interface HeatbugModelSwarm: Swarm
 {
@@ -24,19 +21,21 @@
   int minOutputHeat, maxOutputHeat;
   double randomMoveProbability;
 
+  BOOL randomizeHeatbugUpdateOrder;
   id modelActions;				  // scheduling data structures
   id modelSchedule;
 
   id heatbugList;				  // list of all the heatbugs
-  Grid2d *world;				  // objects representing
+  id <Grid2d> world;				  // objects representing
   HeatSpace *heat;				  // the world
 }
 
 - getHeatbugList;				  // access methods into the
-- (Grid2d *)getWorld;				  // model swarm. These methods
-- (HeatSpace *)getHeat;				  // allow the model swarm to
+- (id <Grid2d>)getWorld;			  // model swarm. These methods
+- (HeatSpace *)getHeat;                           // allow the model swarm to
 						  // be observed.
-
+- (BOOL)toggleRandomizedOrder;                    // method to toggle the
+                                                  // randomization feature
 - addHeatbug: (Heatbug *)bug;			  // special method for demo
 
 + createBegin: aZone;				  // extra methods you
