@@ -4,8 +4,8 @@
 // See file LICENSE for details and terms of copying.
 
 #import "HeatbugModelSwarm.h"
-#import <simtools.h>
 #import <random.h>
+#import <space.h>
 
 @implementation HeatbugModelSwarm
 
@@ -19,16 +19,23 @@
   return heatbugList;
 }
 
-- getWorld
+- (id <Grid2d>)getWorld
 {
   return world;
 }
 
-- getHeat
+- (HeatSpace *)getHeat
 {
   return heat;
 }
 
+- (BOOL)toggleRandomizedOrder
+{
+  randomizeHeatbugUpdateOrder = 
+    ( (randomizeHeatbugUpdateOrder == NO) ? YES : NO );
+  return (randomizeHeatbugUpdateOrder);
+}
+
 // This method isn't normally used, but is convenient when running probes:
 // it lets you easily clone a heatbug and drag it into the model.
 
@@ -61,6 +68,7 @@
   obj->maxIdealTemp = 31000;
   obj->minOutputHeat = 3000;
   obj->maxOutputHeat = 10000;
+  obj->randomizeHeatbugUpdateOrder = NO;
   obj->randomMoveProbability = 0.0;
 
   // And build a customized probe map. Without a probe map, the default
@@ -91,6 +99,9 @@
 				    inClass: [self class]]]; 
   [probeMap addProbe: [probeLibrary getProbeForVariable: "evaporationRate"
 				    inClass: [self class]]];
+  [probeMap addProbe: [probeLibrary getProbeForMessage: 
+                                      "toggleRandomizedOrder" 
+                                    inClass: [self class]]];
   [probeMap addProbe: [probeLibrary getProbeForVariable: "randomMoveProbability"
 				    inClass: [self class]]];
 
@@ -134,7 +145,7 @@
   // The heatspace agent represents the spatial property of heat.
   // It is initialized via various model parameters.
 
-  heat = [HeatSpace createBegin: [self getZone]];
+  heat = [HeatSpace createBegin: self];
   [heat setSizeX: worldXSize Y: worldYSize];
   [heat setDiffusionConstant: diffuseConstant];
   [heat setEvaporationRate: evaporationRate];
@@ -142,13 +153,13 @@
 
   // Now set up the grid used to represent agent position
 
-  world = [Grid2d createBegin: [self getZone]];
+  world = [Grid2d createBegin: self];
   [world setSizeX: worldXSize Y: worldYSize];
   world = [world createEnd];
 
   // Create a list to keep track of the heatbugs in the model.
 
-  heatbugList = [List create: [self getZone]];
+  heatbugList = [List create: self];
   
   // Create heatbugs themselves. This is a fairly complex step, as is
   // appropriate: the heatbugs are essential aspects of the simulation.
@@ -170,9 +181,6 @@
       // Choose a random ideal temperature, output heat from the specified
       // range (model parameters).
       
-      //    idealTemp = [uniformRandom rMin: minIdealTemp Max: maxIdealTemp];
-      //    outputHeat = [uniformRandom rMin: minOutputHeat Max: maxOutputHeat];
-      
       idealTemp = [uniformIntRand
                     getIntegerWithMin: minIdealTemp withMax: maxIdealTemp];
       outputHeat = [uniformIntRand
@@ -181,7 +189,7 @@
       
       // Create the heatbug, set the creation time variables
       
-      hbug = [Heatbug createBegin: [self getZone]];
+      hbug = [Heatbug createBegin: self];
       [hbug setWorld: world Heat: heat];
       hbug = [hbug createEnd];
       
@@ -195,9 +203,6 @@
       [hbug setOutputHeat: outputHeat];
       [hbug setRandomMoveProbability: randomMoveProbability];
       
-      //    [hbug setX: [uniformRandom rMax: worldXSize]  // random position
-      //	  Y: [uniformRandom rMax: worldYSize]];
-
       [hbug setX: [uniformIntRand
                     getIntegerWithMin: 0L
                     withMax: (worldXSize-1)]  // random position
@@ -226,9 +231,24 @@
   // then run "updateWorld" to actually enact the changes the heatbugs
   // have made. The ordering here is significant!
 
-  modelActions = [ActionGroup create: [self getZone]];
+  // Note also, that with the additional `randomizeHeatbugUpdateOrder'
+  // Boolean flag we can randomize the order in which the bugs
+  // actually run their step rule.  This has the effect of removing
+  // any systematic bias in the iteration throught the heatbug list
+  // from timestep to timestep
+
+  // By default, all `createActionForEach' modelActions have a default
+  // order of `Sequential', which means that the order of iteration
+  // through the `heatbugList' will be identical (assuming the list
+  // order is not changed indirectly by some other process).
+
+  modelActions = [ActionGroup create: self];
   [modelActions createActionTo:      heat        message: M(stepRule)];
-  [modelActions createActionForEach: heatbugList message: M(step)];  
+  if (randomizeHeatbugUpdateOrder == YES)
+    [[modelActions createActionForEach: heatbugList message: M(step)] 
+      setDefaultOrder: Randomized];
+  else
+    [modelActions createActionForEach: heatbugList message: M(step)];  
   [modelActions createActionTo:      heat        message: M(updateLattice)];
 
   // Then we create a schedule that executes the modelActions. modelActions
@@ -241,7 +261,7 @@
   // This is a simple schedule, with only one action that is just
   // repeated every time. See mousetraps for more complicated schedules.
   
-  modelSchedule = [Schedule createBegin: [self getZone]];
+  modelSchedule = [Schedule createBegin: self];
   [modelSchedule setRepeatInterval: 1];
   modelSchedule = [modelSchedule createEnd];
   [modelSchedule at: 0 createAction: modelActions];
