@@ -3,11 +3,11 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <objectbase.h>
+#import <objectbase/Swarm.h>
 #import "Counter.h"
 #import "Person.h"
 
-@interface PplModelSwarm : Swarm
+@interface PplModelSwarm: Swarm
 {
   // MODIFY: add your own simulation parameters
   int increment;
@@ -24,7 +24,7 @@
   id modelSchedule;
 
   // MODIFY: add your own model objects.  
-  Counter * counter;
+  Counter *counter;
 }
 
 // MODIFY: add access methods for what agents are visible.
