@@ -11,7 +11,7 @@
 
 */
 
-#import <simtools.h>
+#import <random.h>
 #import "VNneighbor.h"
 
 
