@@ -111,8 +111,8 @@ static unsigned numPredictorsToShow = 7;
             notificationMethod: @selector(_histogramDeath_:)];
 
   [useHisto setWidth: 400 Height: 250];
-  [useHisto setLabels: pred];
-  [useHisto setColors: predictorColors];
+  [useHisto setLabels: pred count: numPredictorsToShow];
+  [useHisto setColors: predictorColors count: numPredictorsToShow];
   [useHisto setTitle: "Usage of predictors"];
   [useHisto setAxisLabelsX: "predictor index" Y: "usage of predictor"];
   [useHisto pack];
